/* ==========================================================================
// internal variables, dependencies, etc
========================================================================== */

import {Tag} from './Tag';
import {User} from './User';
import {Like} from './Like';
import {File} from './File';
import {Image} from './Image';
import {Comment} from './Comment';
import {PostStats} from './PostStats';
import {Cache} from './Cache';
import $ from 'jquery';

/* ==========================================================================
// classes
========================================================================== */

class Post {

  constructor(json = {}) {
    // set default properties
    this.id = '';
    this.createdAt = new Date();
    this.updatedAt = new Date();
    this.type = 'audio';
    this.viewCount = 0;
    this.images = null;
    this.title = '';
    this.description = '';
    this.public = true;
    this.promoted = false;
    this.userId = null;
    this.user = null;
    this.statistics = null;
    this.files = null;
    this.comments = [];
    this.albums = [];
    this.likes = [];
    this.tags = [];

    // check json for keys to set values
    if (json.type) {
      this.type = json.type;
    }

    if (json.id) {
        this.id = json.id;
    }

    if (json.createdAt) {
        this.createdAt = new Date(json.createdAt);
    }

    if (json.updatedAt) {
        this.updatedAt = new Date(json.updatedAt);
    }

    if (json.title) {
        this.title = json.title;
    }

    if (json.comments && json.comments instanceof Array) {
      for (let comment of json.comments) {
        this.comments.push(new Comment(comment));
      }
    }

    if (json.files) {
        this.files = new File(json.files);
        this.files.type = this.type;
    }

    if (json.images) {
        this.images = new Image(json.images);
    }

    if (json.user) {
        this.user = new User(json.user);
    }

    // custom properties
    this.internalId = 'post' + this.id;
    this.isFirstTimeViewing = true;

    if (Cache.get(this.internalId)) {
        this.isFirstTimeViewing = false;
    }
  }

  get link() {
    return window.location.href;
  }

  get hasViewed() {
    let _hasViewed = Cache.get(this.internalId);
    return _hasViewed ? true : false;
  }

  markAsViewed() {
    // set cookie
    Cache.set(this.internalId, 'true');

    // make request to server to lock resource
    let baseURL = 'https://staging.api.skrapps.com/ghosts/';
    let url = baseURL + this.id;
    $.ajax(url, {
        method: 'PUT',
        data: {
            viewed: true,
        },
    }).done(function() {
        console.log('marked as viewed');
    });
  }

  getShareURL(callback) {
    if (this.shareURL) {
        return this.shareURL;
    }

    // TODO: get share URL from server
    this.shareURL = window.location.href;

    callback(this.shareURL);
  }
};

/* ==========================================================================
// exports
========================================================================== */

export { Post as Post };